package com.lzmispt.data.resource.service.collectiontool.impl;

package .tmp;

import com.lzmispt.core.entity.vo.login.LoginVO;
import com.lzmispt.data.resource.dao.metadata.IMetadataDao;
import com.lzmispt.data.resource.entity.dto.collectiontool.ExcelReaderParameter;
import com.lzmispt.data.resource.entity.po.collectiontool.ExcelSheetPO;
import com.lzmispt.data.resource.entity.po.collectiontool.ExcelTemplatePO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataEntityInfoItemPO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataEntityPO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataEntityRelationsPO;
import com.lzmispt.data.resource.manager.metadata.MetadataManager;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.util.SimpleCacheUtil;
import com.lzmispt.framework.entity.dto.excel.ExcelSheetConfigDTO;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ExcelImportContext {
  private final Boolean isByDirectoryIdImport;
  
  private final String platCode;
  
  private final String tokenId;
  
  private final Long userId;
  
  private final LoginVO loginInfo;
  
  private final IMetadataDao metadataDao;
  
  private ExcelReaderParameter excelReaderParams;
  
  private Integer dataResourceCategory;
  
  private final Map<ExcelSheetPO, ExcelSheetConfigDTO> configSource = new HashMap<>();
  
  private final ExcelTemplatePO excelTemplatePo;
  
  private final List<ExcelSheetPO> excelSheetPoList;
  
  private final Map<Long, List<MetadataEntityInfoItemPO>> entityInfoItemsCache = new HashMap<>();
  
  private final Map<Long, List<MetadataEntityRelationsPO>> entityParentRelationsCache = new HashMap<>();
  
  private final Map<Long, MetadataEntityPO> entityCache = new HashMap<>();
  
  public ExcelImportContext(ExcelTemplatePO excelTemplatePo, List<ExcelSheetPO> excelSheetPoList, Boolean isByDirectoryIdImport, String platCode, String tokenId, LoginVO loginInfo, Integer dataResourceCategory, Long userId) {
    this.excelTemplatePo = excelTemplatePo;
    this.excelSheetPoList = excelSheetPoList;
    this.isByDirectoryIdImport = isByDirectoryIdImport;
    this.platCode = platCode;
    this.tokenId = tokenId;
    this.loginInfo = loginInfo;
    this.dataResourceCategory = dataResourceCategory;
    this.userId = userId;
    this.metadataDao = (IMetadataDao)ServiceUtil.getMetadataDao(platCode, IMetadataDao.class);
  }
  
  public List<MetadataEntityInfoItemPO> getEntityInfoItemsByEntityId(Long entityId, Integer dataResourceCategory, String platCode, String tokenId) {
    return (List<MetadataEntityInfoItemPO>)SimpleCacheUtil.cacheGet(this.entityInfoItemsCache, entityId, () -> MetadataManager.getEntityInfoItemsByEntityId(entityId, dataResourceCategory, platCode, tokenId));
  }
  
  public MetadataEntityPO selectEntityByEntityId(Long entityId, Integer dataResourceCategory, String platCode, String tokenId) {
    return (MetadataEntityPO)SimpleCacheUtil.cacheGet(this.entityCache, entityId, () -> MetadataManager.selectEntityByEntityId(entityId, dataResourceCategory, platCode, tokenId));
  }
  
  public List<MetadataEntityRelationsPO> getParentRelationsByEntityId(Long entityId, Integer dataResourceCategory) {
    return (List<MetadataEntityRelationsPO>)SimpleCacheUtil.cacheGet(this.entityParentRelationsCache, entityId, () -> this.metadataDao.getParentRelationsByEntityId(entityId));
  }
  
  public ExcelReaderParameter getExcelReaderParams() {
    return this.excelReaderParams;
  }
  
  public void setExcelReaderParams(ExcelReaderParameter excelReaderParams) {
    this.excelReaderParams = excelReaderParams;
  }
  
  public Map<ExcelSheetPO, ExcelSheetConfigDTO> getConfigSource() {
    return this.configSource;
  }
  
  public ExcelTemplatePO getExcelTemplatePo() {
    return this.excelTemplatePo;
  }
  
  public List<ExcelSheetPO> getExcelSheetPoList() {
    return this.excelSheetPoList;
  }
  
  public Boolean getByDirectoryIdImport() {
    return this.isByDirectoryIdImport;
  }
  
  public String getPlatCode() {
    return this.platCode;
  }
  
  public String getTokenId() {
    return this.tokenId;
  }
  
  public LoginVO getLoginInfo() {
    return this.loginInfo;
  }
  
  public Integer getDataResourceCategory() {
    return this.dataResourceCategory;
  }
  
  public void setDataResourceCategory(Integer dataResourceCategory) {
    this.dataResourceCategory = dataResourceCategory;
  }
  
  public Long getUserId() {
    return this.userId;
  }
}
